BlackWidow
==========

Visualizing Python Project Import Graphs

Installation:

::

    sudo pip install blackwidow

Demo with:

::

    python -m blackwidow.web [module_name]

| Sample results (for Kenneth Reitz's ``requests`` library):
| |Requests Project Graph|

.. |Requests Project Graph| image:: http://i.imgur.com/Q5P8z0Q.png
